@@ -1,5 +1,4 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
 """
 Regexes for reference matching
 
@@ -7,8 +6,6 @@ Web url matching:
 * http://daringfireball.net/2010/07/improved_regex_for_matching_urls
 * https://gist.github.com/gruber/8891611
 """
-from __future__ import absolute_import, division, print_function,\
- unicode_literals
 
 import re
 
